Welcome to gwrappy's documentation!
===================================

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Contents:

.. toctree::
    :maxdepth: 2

    readme
    installation
    usage

Documentation
-------------

.. toctree::
    :maxdepth: 1

    modules/bigquery
    modules/storage
    modules/drive
    modules/gmail
